aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartin Robertz <dream-master@gmx.net>2022-12-17 20:19:00 +0100
committerMartin Robertz <dream-master@gmx.net>2022-12-17 20:19:00 +0100
commit9dd5247e20ef96b5131308a592a405bc4c169322 (patch)
treed5612a0211d3321e061dfa8a71a9c48dc7ad5ca3
parent58eb0fa7aaeb177ba9514e95c2b0e6570320a6cb (diff)
downloadGT5-Unofficial-9dd5247e20ef96b5131308a592a405bc4c169322.tar.gz
GT5-Unofficial-9dd5247e20ef96b5131308a592a405bc4c169322.tar.bz2
GT5-Unofficial-9dd5247e20ef96b5131308a592a405bc4c169322.zip
Update BS
-rw-r--r--build.gradle23
1 files changed, 17 insertions, 6 deletions
diff --git a/build.gradle b/build.gradle
index 6b37de6a3d..d7d5e4c3b9 100644
--- a/build.gradle
+++ b/build.gradle
@@ -1,4 +1,4 @@
-//version: 1669411416
+//version: 1671234391
/*
DO NOT CHANGE THIS FILE!
Also, you may replace this file at any time if there is an update available.
@@ -31,7 +31,7 @@ buildscript {
url 'https://maven.minecraftforge.net'
}
maven {
// GTNH ForgeGradle Fork
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"
}
@@ -45,7 +45,9 @@ buildscript {
}
}
dependencies {
- classpath 'net.minecraftforge.gradle:ForgeGradle:1.2.11'
+ //Overwrite the current ASM version to fix shading newer than java 8 applicatations.
+ classpath 'org.ow2.asm:asm-debug-all-custom:5.0.3'
+ classpath 'net.minecraftforge.gradle:ForgeGradle:1.2.13'
}
}
plugins {
@@ -330,6 +332,12 @@ repositories {
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"
}
+ if (usesMixinDebug.toBoolean()) {
+ maven {
+ name = "Fabric Maven"
+ url = "https://maven.fabricmc.net/"
+ }
+ }
}
}
@@ -338,10 +346,13 @@ dependencies {
annotationProcessor('org.ow2.asm:asm-debug-all:5.0.3')
annotationProcessor('com.google.guava:guava:24.1.1-jre')
annotationProcessor('com.google.code.gson:gson:2.8.6')
- annotationProcessor('org.spongepowered:mixin:0.8.5-GTNH:processor')
+ annotationProcessor('com.gtnewhorizon:gtnhmixins:2.1.3:processor')
+ if (usesMixinDebug.toBoolean()) {
+ runtimeOnly('org.jetbrains:intellij-fernflower:1.2.1.16')
+ }
}
if (usesMixins.toBoolean() || forceEnableMixins.toBoolean()) {
- compile('com.gtnewhorizon:gtnhmixins:2.0.2')
+ compile('com.gtnewhorizon:gtnhmixins:2.1.3')
}
}
@@ -694,7 +705,7 @@ if (modrinthProjectId.size() != 0 && System.getenv("MODRINTH_TOKEN") != null) {
}
}
if (usesMixins.toBoolean()) {
- addModrinthDep("required", "version", "gtnhmixins")
+ addModrinthDep("required", "project", "gtnhmixins")
}
tasks.modrinth.dependsOn(build)
tasks.publish.dependsOn(tasks.modrinth)
@@ -31,7 +31,7 @@ buildscript {
}
maven {
- // GTNH ForgeGradle Fork
+ // GTNH ForgeGradle and ASM Fork
name = "GTNH Maven"
url = "http://jenkins.usrv.eu:8081/nexus/content/groups/public/"